@@ -29,6 +29,7 @@
 #include <gnome.h>
 
 #include "gst.h"
+#include "gst-hig-dialog.h"
 #include "gst-report-hook.h"
 #include "boot-druid.h"
 #include "boot-settings.h"
@@ -272,24 +273,46 @@ on_boot_table_cursor_changed (GtkTreeSelection *selection, gpointer data)
 	callbacks_actions_set_sensitive (TRUE);	
 }
 
+static void
+do_popup_menu (GtkWidget *popup, GdkEventButton *event)
+{
+	gint button, event_time;
+
+	if (!popup)
+		return;
+
+	if (event) {
+		button     = event->button;
+		event_time = event->time;
+	} else {
+		button     = 0;
+		event_time = gtk_get_current_event_time ();
+	}
+
+	gtk_menu_popup (GTK_MENU (popup), NULL, NULL, NULL, NULL,
+			button, event_time);
+}
+
 gboolean
 on_boot_table_button_press (GtkTreeView *treeview, GdkEventButton *event, gpointer gdata)
 {
 	GtkTreePath *path;
-	GtkItemFactory *factory;
+	GtkWidget   *popup_menu;
 
-	factory = (GtkItemFactory *) gdata;
+	popup_menu = (GtkWidget*) gdata;
 
-	if (event->button == 3)
-	{
+	if (event->type == GDK_2BUTTON_PRESS || event->type == GDK_3BUTTON_PRESS) {
+		on_boot_settings_clicked (NULL, NULL);
+		return TRUE;
+	}
+	
+	if (event->button == 3)	{
 		gtk_widget_grab_focus (GTK_WIDGET (treeview));
-		if (gtk_tree_view_get_path_at_pos (treeview, event->x, event->y, &path, NULL, NULL, NULL))
-		{
+		if (gtk_tree_view_get_path_at_pos (treeview, event->x, event->y, &path, NULL, NULL, NULL)) {
 			gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (treeview));
 			gtk_tree_selection_select_path (gtk_tree_view_get_selection (treeview), path);
 
-			gtk_item_factory_popup (factory, event->x_root, event->y_root,
-						event->button, event->time);
+			do_popup_menu (popup_menu, event);
 		}
 		return TRUE;
 	}
@@ -313,19 +336,19 @@ on_use_password_clicked (GtkWidget *use_password, gpointer gdata)
 }
 
 void
-on_popup_add_activate (gpointer callback_data, guint action, GtkWidget *widget)
+on_popup_add_activate (GtkAction *action, gpointer callback_data)
 {
 	on_boot_add_clicked (callback_data, NULL);
 }
 
 void
-on_popup_settings_activate (gpointer callback_data, guint action, GtkWidget *widget)
+on_popup_settings_activate (GtkAction *action, gpointer callback_data)
 {
 	on_boot_settings_clicked (callback_data, NULL);
 }
 
 void
-on_popup_delete_activate (gpointer callback_data, guint action, GtkWidget *widget)
+on_popup_delete_activate (GtkAction *action, gpointer callback_data)
 {
 	on_boot_delete_clicked (callback_data, NULL);
 }
@@ -375,7 +398,7 @@ on_boot_delete_clicked (GtkButton *button, gpointer data)
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	xmlNodePtr   node;
-	gchar       *label, *buf;
+	gchar       *label;
 	gint         count, reply;
 	GtkWidget   *d;
 	
@@ -383,13 +406,14 @@ on_boot_delete_clicked (GtkButton *button, gpointer data)
 
 	count = boot_image_count (gst_xml_doc_get_root (tool->config));
 	if (count <= 1) {
-		d = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
-					    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-					    GTK_MESSAGE_ERROR,
-					    GTK_BUTTONS_OK,
-					    _("Without at least one boot image,\n"
-					      "your system will not start.\n"));
-
+		d = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
+					GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+					GST_HIG_MESSAGE_ERROR,
+					_("Error deleting boot image"),
+					_("Without at least one boot image "
+					  "your computer will not start"),
+					GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+					NULL);
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (d);
 		return;
@@ -402,20 +426,24 @@ on_boot_delete_clicked (GtkButton *button, gpointer data)
 	}
 	
 	label = gst_xml_get_child_content (node, "label");
-	buf = g_strdup_printf (_("Are you sure you want to delete '%s'?"), label);
+
+	d = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
+				GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+				GST_HIG_MESSAGE_QUESTION,
+				NULL,
+				_("This may leave this operating system unbootable"),
+				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				GTK_STOCK_DELETE, GTK_RESPONSE_ACCEPT,
+				NULL);
+	gst_hig_dialog_set_primary_text (GST_HIG_DIALOG (d),
+					 _("Are you sure you want to delete \"%s\"?"), label);
+
+	reply = gtk_dialog_run (GTK_DIALOG (d));
+
+	gtk_widget_destroy (d);
 	g_free (label);
 
-	d = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
-				    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-				    GTK_MESSAGE_QUESTION,
-				    GTK_BUTTONS_YES_NO,
-				    buf);
-
-	g_free (buf);
-	reply = gtk_dialog_run (GTK_DIALOG (d));
-	gtk_widget_destroy (d);
-
-	if (reply != GTK_RESPONSE_YES)
+	if (reply != GTK_RESPONSE_ACCEPT)
 		return;
 
 	gst_xml_element_destroy (node);
@@ -445,18 +473,16 @@ gboolean
 callbacks_conf_read_failed_hook (GstTool *tool, GstReportLine *rline, gpointer data)
 {
 	GtkWidget *dialog;
-	gchar *txt;
 
-	txt = g_strdup_printf (_("The file ``%s'' is missing or could not be read:\n"
-				 "The configuration will show empty."), rline->argv[0]);
-
-	dialog = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
-					 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-					 GTK_MESSAGE_ERROR,
-					 GTK_BUTTONS_OK,
-					 txt);
-
-	g_free (txt);
+	dialog = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
+				     GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+				     GST_HIG_MESSAGE_ERROR,
+				     _("The configuration will show empty"),
+				     NULL,
+				     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+				     NULL);
+	gst_hig_dialog_set_primary_text (GST_HIG_DIALOG (dialog),
+					 _("The file \"%s\" is missing or could not be read"), rline->argv[0]);
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
