@@ -53,7 +53,6 @@ struct _GstTool {
 	char *glade_path;
 	char *glade_common_path;
 	char *script_path;
-	char *etspecs_common_path;
 
 	char *script_name;
 
@@ -92,9 +91,6 @@ struct _GstTool {
 	GtkWidget *report_window;
 	GtkWidget *report_label;
 
-	gboolean timeout_done;
-	gboolean report_list_visible;
-
 	GString *line;
 	GString *xml_document;
 	
@@ -177,7 +173,9 @@ void         gst_tool_clear_supported_platforms (GstTool *tool);
 
 void         gst_tool_process_startup (GstTool*);
 
-gchar*       gst_tool_read_from_backend (GstTool*);
+gchar*       gst_tool_read_from_backend (GstTool*, gchar*, ...);
+gchar*       gst_tool_read_line_from_backend (GstTool*);
+void         gst_tool_read_junk_from_backend (GstTool*, gchar*);
 void         gst_tool_write_to_backend (GstTool*, gchar*);
 void         gst_tool_write_xml_to_backend (GstTool*, xmlDoc*);
 
