@@ -69,13 +69,39 @@ on_network_admin_show (GtkWidget *w, gpointer user_data)
 	profiles_table_create (tool);
 }
 
+static void
+do_popup_menu (GtkTreeView *treeview, GtkWidget *popup, GdkEventButton *event)
+{
+	GtkTreeSelection *selection;
+	GtkUIManager     *ui_manager;
+	gint              cont, button, event_time;
+
+	selection = gtk_tree_view_get_selection (treeview);
+	cont = gtk_tree_selection_count_selected_rows (selection);
+
+	if (!cont)
+		return;
+
+	if (event) {
+		button     = event->button;
+		event_time = event->time;
+	} else {
+		button     = 0;
+		event_time = gtk_get_current_event_time ();
+	}
+
+	gtk_menu_popup (GTK_MENU (popup),
+			NULL, NULL, NULL, NULL,
+			button, event_time);
+}
+
 gboolean
 callbacks_button_press (GtkTreeView *treeview, GdkEventButton *event, gpointer gdata)
 {
 	GtkTreePath *path;
-	GtkItemFactory *factory;
+	GtkWidget   *popup;
 
-	factory = (GtkItemFactory *) gdata;
+	popup = GTK_WIDGET (gdata);
 
 	if (event->button == 3)
 	{
@@ -85,14 +111,20 @@ callbacks_button_press (GtkTreeView *treeview, GdkEventButton *event, gpointer g
 			gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (treeview));
 			gtk_tree_selection_select_path (gtk_tree_view_get_selection (treeview), path);
 
-			gtk_item_factory_popup (factory, event->x_root, event->y_root,
-						event->button, event->time);
+			do_popup_menu (treeview, popup, event);
 		}
 		return TRUE;
 	}
 	return FALSE;
 }
 
+gboolean
+on_table_popup_menu (GtkTreeView *treeview, GtkWidget *popup)
+{
+	do_popup_menu (treeview, popup, NULL);
+	return TRUE;
+}
+
 void
 on_network_notebook_switch_page (GtkWidget *notebook, GtkNotebookPage *page,
 				 gint page_num, gpointer user_data)
@@ -362,7 +394,7 @@ on_connection_delete_clicked (GtkWidget *w, gpointer null)
 				GTK_DIALOG_MODAL,
 				GST_HIG_MESSAGE_QUESTION,
 				NULL,
-				_("This will disable any network connection with this interface as soon as you hit \"apply\"."),
+				_("This will disable any network connection with this interface as soon as you press \"apply\""),
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				GTK_STOCK_DELETE, GTK_RESPONSE_ACCEPT,
 				NULL);
@@ -389,19 +421,19 @@ on_connection_configure_clicked (GtkWidget *w, gpointer null)
 }
 
 void
-on_connection_popup_add_activate (gpointer callback_data, guint action, GtkWidget *widget)
+on_connection_popup_add_activate (GtkAction *action, gpointer callback_data)
 {
 	on_connection_add_clicked (callback_data, NULL);
 }
 
 void
-on_connection_popup_configure_activate (gpointer callback_data, guint action, GtkWidget *widget)
+on_connection_popup_configure_activate (GtkAction *action, gpointer callback_data)
 {
 	on_connection_configure_clicked (callback_data, NULL);
 }
 
 void
-on_connection_popup_delete_activate (gpointer callback_data, guint action, GtkWidget *widget)
+on_connection_popup_delete_activate (GtkAction *action, gpointer callback_data)
 {
 	on_connection_delete_clicked (callback_data, NULL);
 }
@@ -438,6 +470,24 @@ on_connection_deactivate_button_clicked (GtkWidget *widget, gpointer data)
 	connection_enable (cxn, FALSE);
 }
 
+void
+on_connection_default_gw_activate (GtkWidget *widget, gpointer data)
+{
+	GtkTreeModel *model;
+	GtkTreeIter   iter;
+	gchar        *gw;
+
+	model = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
+
+	if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (widget), &iter)) {
+		gtk_tree_model_get (model, &iter, 0, &gw, -1);
+		g_object_steal_data (G_OBJECT (tool), "gatewaydev");
+
+		g_object_set_data (G_OBJECT (tool), "gatewaydev", data);
+		g_free (gw);
+	}
+}
+
 void
 on_samba_use_toggled (GtkWidget *w, gpointer null)
 {
@@ -459,7 +509,7 @@ on_samba_use_toggled (GtkWidget *w, gpointer null)
 					     GST_HIG_MESSAGE_INFO,
 					     _("SMB Support is not running"),
 					     _("You don't have SMB support installed. Please install "
-					       "SMB support in the system to enable windows networking."),
+					       "SMB support in the system to enable file sharing in Windows networks"),
 					     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 					     NULL);
 		gtk_dialog_run (GTK_DIALOG (dialog));
@@ -522,7 +572,7 @@ callbacks_check_hostname_hook (GstDialog *dialog, gpointer data)
 		message = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
 					      GTK_DIALOG_MODAL,
 					      GST_HIG_MESSAGE_WARNING,
-					      _("Host name has changed"),
+					      _("The host name has changed"),
 					      _("This will prevent you "
 						"from launching new applications, and so you will "
 						"have to log in again. Continue anyway?"),
@@ -570,10 +620,10 @@ callbacks_check_dialer (GtkWindow *window, GstTool *tool)
 		message = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
 					      GTK_DIALOG_MODAL,
 					      GST_HIG_MESSAGE_WARNING,
-					      _("Wvdial missing"),
+					      _("Wvdial command not found"),
 					      _("wvdial could not be found on your system. "
 						"You need to install wvdial, or the PPP (modem) "
-						"connections will not activate."),
+						"connections will not activate"),
 					      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 					      NULL);
 		gtk_dialog_run (GTK_DIALOG (message));
@@ -597,7 +647,7 @@ callbacks_check_dialer_hook (GstDialog *dialog, gpointer data)
 		message = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
 					      GTK_DIALOG_MODAL,
 					      GST_HIG_MESSAGE_WARNING,
-					      _("Wvdial not found"),
+					      _("Wvdial command not found"),
 					      _("wvdial could not be found on your system. "
 						"You need to install wvdial, or the PPP (modem) "
 						"connections will not activate. Continue anyway?"),
@@ -676,7 +726,7 @@ callbacks_check_manual_gatewaydev (GstTool *tool)
 						     GST_HIG_MESSAGE_ERROR,
 						     _("The default gateway device is missing gateway information"),
 						     _("Please provide this information to "
-						       "proceed, or choose another default gateway device."),
+						       "proceed, or choose another default gateway device"),
 						     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 						     NULL);
 			gtk_dialog_run (GTK_DIALOG (dialog));
@@ -723,7 +773,7 @@ callbacks_tool_not_found_hook (GstTool *tool, GstReportLine *rline, gpointer dat
 					      _("The program redhat-config-network-cmd could not be found"),
 					      _("This could render missing connections "
 						"under the connections tab. Please install the "
-						"redhat-config-network rpm package to avoid this."),
+						"redhat-config-network rpm package to avoid this"),
 					      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 					      NULL);
 		gtk_dialog_run (GTK_DIALOG (message));
@@ -841,11 +891,34 @@ on_connection_modified (GtkWidget *w, gpointer data)
 	connection_set_modified (cxn, TRUE);
 }
 
+void
+on_connection_ip_config_changed (GtkWidget *w, gpointer data)
+{
+       GstConnection *cxn;
+       IPConfigType ip;
+
+       cxn = g_object_get_data (G_OBJECT (w), "cxn");
+
+       if (cxn->frozen)
+               return;
+
+       ip = gtk_combo_box_get_active (GTK_COMBO_BOX (w));
+
+       if (cxn->tmp_ip_config == ip)
+               return;
+
+       cxn->tmp_ip_config = ip;
+
+       connection_set_modified (cxn, TRUE);
+
+       connection_update_ip_config (cxn);
+}
+
 void
 on_ppp_autodetect_modem_clicked (GtkWidget *widget, gpointer data)
 {
 	GtkWidget *autodetect_button = gst_dialog_get_widget (tool->main_dialog, "ppp_autodetect_modem");
-	GtkWidget *devices_combo = gst_dialog_get_widget (tool->main_dialog, "ppp_serial_port_g");
+	GtkWidget *devices_combo = gst_dialog_get_widget (tool->main_dialog, "ppp_serial_port");
 	GtkWidget *dialog = gst_dialog_get_widget (tool->main_dialog, "connection_config_dialog");
 	GtkWidget *w;
 	gchar *dev;
@@ -866,15 +939,14 @@ on_ppp_autodetect_modem_clicked (GtkWidget *widget, gpointer data)
 					GTK_DIALOG_MODAL,
 					GST_HIG_MESSAGE_WARNING,
 					_("Could not autodetect modem device"),
-					_("Check that it's not busy and that it's correctly attached"),
+					_("Check that the device is not busy and "
+					  "that is correctly attached to the computer"),
 					GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 					NULL);
 		gtk_dialog_run (GTK_DIALOG (w));
 		gtk_widget_destroy (w);
-	} else {
-		w = gst_dialog_get_widget (tool->main_dialog, "ppp_serial_port");
-		gtk_entry_set_text (GTK_ENTRY (w), dev);
-	}
+	} else
+		gtk_entry_set_text (GTK_ENTRY (GTK_BIN (GTK_COMBO_BOX (devices_combo))->child), dev);
 
 	if (dev)
 		g_free (dev);
@@ -1035,7 +1107,7 @@ on_dns_search_entry_changed (GtkWidget *widget, gpointer gdata)
 }
 
 void
-on_dns_search_popup_del_activate (gpointer callback_data, guint action, GtkWidget *widget)
+on_dns_search_popup_del_activate (GtkAction *action, gpointer callback_data)
 {
 	on_dns_search_del_button_clicked (callback_data, NULL);
 }
@@ -1207,7 +1279,7 @@ on_hosts_delete_clicked (GtkWidget * button, gpointer user_data)
 }
 
 void
-on_hosts_popup_del_activate (gpointer callback_data, guint action, GtkWidget *widget)
+on_hosts_popup_del_activate (GtkAction *action, gpointer callback_data)
 {
 	on_hosts_delete_clicked (callback_data, NULL);
 }
@@ -1248,7 +1320,7 @@ on_network_druid_page_prepare (GnomeDruidPage *druid_page, GnomeDruid *druid, gp
 	gchar *next_default_focus[] = {
 		NULL,
 		"connection_type_modem_option",
-		"network_connection_wireless_device_entry",
+		"network_connection_wireless_device",
 		"network_connection_other_config_type",
 		"network_connection_plip_local_ip",
 		"network_connection_ppp_phone",
@@ -1313,7 +1385,7 @@ on_network_druid_finish (GnomeDruidPage *druid_page, GnomeDruid *druid, gpointer
 }
 
 void
-on_network_druid_config_type_changed (GtkWidget *option_menu, gpointer data)
+on_network_druid_config_type_changed (GtkWidget *menu, gpointer data)
 {
 	GnomeDruid *druid = GNOME_DRUID (gst_dialog_get_widget (tool->main_dialog,
 								"network_connection_druid"));
@@ -1331,7 +1403,7 @@ on_network_druid_config_type_changed (GtkWidget *option_menu, gpointer data)
 		NULL
 	};
 
-	if (gtk_option_menu_get_history (GTK_OPTION_MENU (option_menu)) == IP_MANUAL)
+	if (gtk_combo_box_get_active (GTK_COMBO_BOX (menu)) == IP_MANUAL)
 		enable = TRUE;
 	else
 		enable = FALSE;
@@ -1448,24 +1520,35 @@ on_network_profile_delete_clicked (GtkWidget *widget, gpointer data)
 void
 on_network_profile_option_selected (GtkWidget *widget, gpointer data)
 {
-	GtkWidget *connection_table = gst_dialog_get_widget (tool->main_dialog, "connection_list");
+	GtkWidget    *connection_table = gst_dialog_get_widget (tool->main_dialog, "connection_list");
 	GtkTreeModel *connection_model = gtk_tree_view_get_model (GTK_TREE_VIEW (connection_table));
-	GtkWidget *statichost_table = gst_dialog_get_widget (tool->main_dialog, "statichost_list");
+	GtkWidget    *statichost_table = gst_dialog_get_widget (tool->main_dialog, "statichost_list");
 	GtkTreeModel *statichost_model = gtk_tree_view_get_model (GTK_TREE_VIEW (statichost_table));
-	GtkWidget *dns_table = gst_dialog_get_widget (tool->main_dialog, "dns_list");
+	GtkWidget    *dns_table = gst_dialog_get_widget (tool->main_dialog, "dns_list");
 	GtkTreeModel *dns_model = gtk_tree_view_get_model (GTK_TREE_VIEW (dns_table));
-	GtkWidget *search_table = gst_dialog_get_widget (tool->main_dialog, "search_list");
+	GtkWidget    *search_table = gst_dialog_get_widget (tool->main_dialog, "search_list");
 	GtkTreeModel *search_model = gtk_tree_view_get_model (GTK_TREE_VIEW (search_table));
-	xmlNodePtr profile = (xmlNodePtr) data;
-	
-	profile_set_active (profile, tool);
+	GtkTreeModel *model;
+	GtkTreeIter   iter;
+	xmlNodePtr    profile;
 
-	gtk_list_store_clear (GTK_LIST_STORE (connection_model));
-	gtk_list_store_clear (GTK_LIST_STORE (statichost_model));
-	gtk_list_store_clear (GTK_LIST_STORE (dns_model));
-	gtk_list_store_clear (GTK_LIST_STORE (search_model));
+	model = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
+
+	if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (widget), &iter)) {
+		gtk_tree_model_get (model, &iter, 1, &profile, -1);
+
+		if (!profile)
+			return;
 	
-	transfer_profile_to_gui (tool, NULL);
+		profile_set_active (profile, tool);
+
+		gtk_list_store_clear (GTK_LIST_STORE (connection_model));
+		gtk_list_store_clear (GTK_LIST_STORE (statichost_model));
+		gtk_list_store_clear (GTK_LIST_STORE (dns_model));
+		gtk_list_store_clear (GTK_LIST_STORE (search_model));
+	
+		transfer_profile_to_gui (tool, NULL);
+	}
 }
 
 void
@@ -1525,3 +1608,26 @@ on_drag_data_received (GtkTreeView *treeview,
 
 	gst_dialog_modify (tool->main_dialog);
 }
+
+GtkWidget *
+create_popup_menu (GtkWidget *widget, GtkActionEntry *menu_items, gint nitems, const gchar *ui_description)
+{
+	GtkUIManager   *ui_manager;
+	GtkActionGroup *action_group;
+	GtkWidget      *popup;
+
+	g_return_val_if_fail (widget != NULL, NULL);
+
+	action_group = gtk_action_group_new ("MenuActions");
+	gtk_action_group_add_actions (action_group, menu_items, nitems, widget);
+
+	ui_manager = gtk_ui_manager_new ();
+	gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
+
+	if (!gtk_ui_manager_add_ui_from_string (ui_manager, ui_description, -1, NULL))
+		return NULL;
+
+	popup = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
+
+	return popup;
+}
