@@ -50,7 +50,8 @@ GstDialogSignal signals[] = {
 	{ "connection_configure",    "clicked",         G_CALLBACK (on_connection_configure_clicked) },
 	{ "connection_activate",     "clicked",         G_CALLBACK (on_connection_activate_button_clicked) },
 	{ "connection_deactivate",   "clicked",         G_CALLBACK (on_connection_deactivate_button_clicked) },
-	{ "connection_def_gw_omenu", "changed",         G_CALLBACK (gst_dialog_modify_cb) },
+	{ "connection_def_gw_menu",  "changed",         G_CALLBACK (on_connection_default_gw_activate) },
+	{ "connection_def_gw_menu",  "changed",         G_CALLBACK (gst_dialog_modify_cb) },
 	{ "domain",                  "changed",         G_CALLBACK (gst_dialog_modify_cb) },
 /*	{ "ip",                      "changed",         G_CALLBACK (gst_dialog_modify_cb) },*/
 	{ "ip",                      "changed",         G_CALLBACK (on_hosts_ip_changed) },
@@ -91,7 +92,7 @@ GstDialogSignal signals[] = {
 	{ "network_connection_ppp_page2",    "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_page_activate", "back",   G_CALLBACK (on_network_druid_page_back) },
 	{ "network_connection_page_finish",  "back",   G_CALLBACK (on_network_druid_page_back) },
-	{ "network_connection_wireless_device_entry", "changed", G_CALLBACK (on_network_druid_entry_changed) },
+	{ "network_connection_wireless_device", "changed", G_CALLBACK (on_network_druid_entry_changed) },
 	{ "network_connection_essid", "changed", G_CALLBACK (on_network_druid_entry_changed) },
 	{ "network_connection_other_config_type", "changed", G_CALLBACK (on_network_druid_config_type_changed) },
 	{ "network_connection_other_ip_address", "changed", G_CALLBACK (on_network_druid_entry_changed) },
@@ -107,6 +108,7 @@ GstDialogSignal signals[] = {
 	{ "network_connection_other_ip_address", "focus_out_event", G_CALLBACK (on_network_druid_ip_address_focus_out) },
 
 	/* Network profiles callbacks */
+	{ "network_profiles_menu", "changed", G_CALLBACK (on_network_profile_option_selected) },
 	{ "network_profiles_button", "clicked", G_CALLBACK (on_network_profiles_button_clicked) },
 	{ "network_profile_new", "clicked", G_CALLBACK (on_network_profile_new_clicked) },
 	{ "network_profile_delete", "clicked", G_CALLBACK (on_network_profile_delete_clicked) },
@@ -123,7 +125,8 @@ GstDialogSignal signals[] = {
 	{ "status_autoboot", "toggled", G_CALLBACK (on_connection_modified) },
 	{ "status_user", "toggled", G_CALLBACK (on_connection_modified) },
 	{ "wlan_essid", "changed", G_CALLBACK (on_connection_modified) },
-	{ "connection_config", "clicked", G_CALLBACK (on_connection_modified) },
+	{ "connection_config", "changed", G_CALLBACK (on_connection_ip_config_changed) },
+	{ "connection_config", "changed", G_CALLBACK (on_connection_modified) },
 	{ "ip_address", "changed", G_CALLBACK (on_connection_modified) },
 	{ "ip_netmask", "changed", G_CALLBACK (on_connection_modified) },
 	{ "ip_gateway", "changed", G_CALLBACK (on_connection_modified) },
@@ -131,8 +134,7 @@ GstDialogSignal signals[] = {
 	{ "ptp_address", "changed", G_CALLBACK (on_connection_modified) },
 	{ "ptp_remote_address", "changed", G_CALLBACK (on_connection_modified) },
 	{ "ptp_remote_is_gateway", "toggled", G_CALLBACK (on_connection_modified) },
-	{ "ppp_serial_port", "changed", G_CALLBACK (on_connection_modified) },
-	{ "ppp_dial_command", "clicked", G_CALLBACK (on_connection_modified) },
+	{ "ppp_dial_command", "changed", G_CALLBACK (on_connection_modified) },
 	{ "ppp_volume", "value_changed", G_CALLBACK (on_connection_modified) },
 	{ "ppp_persist", "toggled", G_CALLBACK (on_connection_modified) },
 	{ "ppp_phone_number", "changed", G_CALLBACK (on_connection_modified) },
@@ -167,8 +169,19 @@ static GstReportHookEntry report_hooks[] = {
 static void
 connect_signals (GstDialog *main_dialog, GstDialogSignal *sigs, GstDialogSignal *sigs_after)
 {
+	GtkWidget *widget;
+	
 	gst_dialog_connect_signals (main_dialog, sigs);
 	gst_dialog_connect_signals_after (main_dialog, sigs_after);
+
+	/* FIXME: do this here until the GtkComboBox child is accessible through glade */
+	widget = gst_dialog_get_widget (main_dialog, "network_connection_wireless_device");
+	g_signal_connect (GTK_BIN (GTK_COMBO_BOX (widget))->child,
+			  "changed", G_CALLBACK (on_network_druid_entry_changed), NULL);
+
+	widget = gst_dialog_get_widget (main_dialog, "ppp_serial_port");
+	g_signal_connect (GTK_BIN (GTK_COMBO_BOX (widget))->child,
+			  "changed", G_CALLBACK (on_connection_modified), NULL);
 }
 
 int
