@@ -32,33 +32,42 @@
 static void
 network_druid_fill_wireless_devices_list (GstTool *tool)
 {
-	GtkWidget *combo = gst_dialog_get_widget (tool->main_dialog,
-						  "network_connection_wireless_device");
-	xmlNodePtr root = gst_xml_doc_get_root (tool->config);
-	xmlNodePtr node;
-	GList *devices = NULL;
-	
+	GtkWidget    *combo;
+	GtkTreeModel *model;
+	xmlNodePtr    root, node;
+
+	root  = gst_xml_doc_get_root (tool->config);
+	combo = gst_dialog_get_widget (tool->main_dialog,
+				       "network_connection_wireless_device");
+
+	model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
+	gtk_list_store_clear (GTK_LIST_STORE (model));
+
 	for (node = gst_xml_element_find_first (root, "wireless_device");
 	     node != NULL;
 	     node = gst_xml_element_find_next (node, "wireless_device"))
 	{
-		devices = g_list_append (devices, gst_xml_element_get_content (node));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (combo),
+					   gst_xml_element_get_content (node));
 	}
-
-	if (devices)
-		gtk_combo_set_popdown_strings (GTK_COMBO (combo), devices);
 }
 
 void
 network_druid_new (GnomeDruid *druid, GtkWidget *window, GstTool *tool, GstConnectionType type)
 {
 	NetworkDruidData *druid_data = g_new0 (NetworkDruidData, 1);
+	GtkWidget *widget;
 
 	druid_data->window = window;
 	druid_data->tool = tool;
 	druid_data->current_page = NETWORK_DRUID_START;
 	druid_data->cxn = connection_new_from_type (type, gst_xml_doc_get_root (tool->config));
 
+	/* fill the IP options menu */
+	widget = gst_dialog_get_widget (tool->main_dialog, "network_connection_other_config_type");
+	connection_fill_ip_menu (widget);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), IP_MANUAL);
+
 	/* set window titles */
 	druid_data->first_page_title = N_("Creating a new network connection");
 	druid_data->title = N_("Creating a new network connection (%d of %d)");
@@ -79,7 +88,6 @@ network_druid_clear (GnomeDruid *druid, gboolean destroy_data)
 	GstTool *tool = druid_data->tool;
 	GtkWidget *widget;
 	gchar *entries [] = {
-		"network_connection_wireless_device_entry",
 		"network_connection_essid",
 		"network_connection_other_ip_address",
 		"network_connection_other_ip_mask",
@@ -99,8 +107,11 @@ network_druid_clear (GnomeDruid *druid, gboolean destroy_data)
 		gtk_entry_set_text (GTK_ENTRY (widget), "");
 	}
 
+	widget = gst_dialog_get_widget (tool->main_dialog, "network_connection_wireless_device");
+	gtk_entry_set_text (GTK_ENTRY (GTK_BIN (widget)->child), "");
+
 	widget = gst_dialog_get_widget (tool->main_dialog, "network_connection_other_config_type");
-	gtk_option_menu_set_history (GTK_OPTION_MENU (widget), IP_MANUAL);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), IP_MANUAL);
 
 	widget = gst_dialog_get_widget (tool->main_dialog, "network_connection_plip_gateway");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), FALSE);
@@ -174,16 +185,16 @@ network_druid_get_connection_data (GnomeDruid *druid)
 
 		if (cxn->type == GST_CONNECTION_WLAN) {
 			GtkWidget *device = gst_dialog_get_widget (tool->main_dialog,
-								   "network_connection_wireless_device_entry");
+								   "network_connection_wireless_device");
 			GtkWidget *essid = gst_dialog_get_widget (tool->main_dialog,
 								  "network_connection_essid");
-			cxn->dev = g_strdup (gtk_entry_get_text (GTK_ENTRY (device)));
+			cxn->dev = g_strdup (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (device)->child)));
 			cxn->essid = g_strdup (gtk_entry_get_text (GTK_ENTRY (essid)));
 		} else {
 			cxn->dev = connection_find_new_device (root, cxn->type);
 		}
 			
-		cxn->ip_config = gtk_option_menu_get_history (GTK_OPTION_MENU (type));
+		cxn->ip_config = gtk_combo_box_get_active (GTK_COMBO_BOX (type));
 		cxn->address = g_strdup (gtk_entry_get_text (GTK_ENTRY (ip_address)));
 		cxn->netmask = g_strdup (gtk_entry_get_text (GTK_ENTRY (ip_mask)));
 		cxn->gateway = g_strdup (gtk_entry_get_text (GTK_ENTRY (gateway)));
@@ -258,14 +269,9 @@ network_druid_check_login_password (GnomeDruid *druid)
 }
 
 static gboolean
-network_druid_check_entry (GnomeDruid *druid, gchar *widget_name)
+network_druid_check_entry (GtkWidget *widget)
 {
-	NetworkDruidData *druid_data = g_object_get_data (G_OBJECT (druid), "data");
-
-	GtkWidget *account = gst_dialog_get_widget (druid_data->tool->main_dialog,
-						    widget_name);
-	gchar *text = (gchar*) gtk_entry_get_text (GTK_ENTRY (account));
-
+	const gchar *text = gtk_entry_get_text (GTK_ENTRY (widget));
 	return (strcmp (text, "") != 0);
 }
 
@@ -274,15 +280,15 @@ network_druid_check_ip (GnomeDruid *druid)
 {
 	NetworkDruidData *druid_data = g_object_get_data (G_OBJECT (druid), "data");
 	GstTool *tool = druid_data->tool;
-	GtkWidget *option_menu = gst_dialog_get_widget (tool->main_dialog,
-							"network_connection_other_config_type");
+	GtkWidget *menu = gst_dialog_get_widget (tool->main_dialog,
+						 "network_connection_other_config_type");
 	GtkWidget *ip_address = gst_dialog_get_widget (tool->main_dialog,
 						       "network_connection_other_ip_address");
 	GtkWidget *ip_mask = gst_dialog_get_widget (tool->main_dialog,
 						    "network_connection_other_ip_mask");
 	const gchar *address, *mask;
 
-	if (gtk_option_menu_get_history (GTK_OPTION_MENU (option_menu)) == IP_MANUAL) {
+	if (gtk_combo_box_get_active (GTK_COMBO_BOX (menu)) == IP_MANUAL) {
 		address = gtk_entry_get_text (GTK_ENTRY (ip_address));
 		mask = gtk_entry_get_text (GTK_ENTRY (ip_mask));
 		return ((strlen (address) != 0) && (strlen (mask) != 0));
@@ -311,11 +317,19 @@ void
 network_druid_check_page (GnomeDruid *druid, NetworkDruidPages page_number)
 {
 	gboolean cont;
+	GtkWidget *wireless_device, *essid;
+	NetworkDruidData *druid_data;
 
 	switch (page_number) {
 	case NETWORK_DRUID_WIRELESS:
-		cont = network_druid_check_entry (druid, "network_connection_wireless_device_entry") &&
-			network_druid_check_entry (druid, "network_connection_essid");
+		druid_data = g_object_get_data (G_OBJECT (druid), "data");
+		wireless_device = gst_dialog_get_widget (druid_data->tool->main_dialog,
+							 "network_connection_wireless_device");
+		essid = gst_dialog_get_widget (druid_data->tool->main_dialog,
+					       "network_connection_essid");
+
+		cont = network_druid_check_entry (GTK_BIN (wireless_device)->child) &&
+			network_druid_check_entry (essid);
 		break;
 	case NETWORK_DRUID_OTHER_1:
 		cont = network_druid_check_ip (druid);
