@@ -38,6 +38,7 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include "gst.h"
+#include "gst-hig-dialog.h"
 #include "time-tool.h"
 
 #include "tz.h"
@@ -190,15 +191,11 @@ gst_time_init_timezone (GstTimeTool *time_tool)
 	gtk_container_add (GTK_CONTAINER (w), GTK_WIDGET (tzmap->map));
 	gtk_widget_show (GTK_WIDGET (tzmap->map));
 
-	locs = tz_get_locations (e_tz_map_get_tz_db (tzmap));
-	
-	for (i = 0; g_ptr_array_index (locs, i); i++) {
-		combo_locs = g_list_append (combo_locs,
-					    g_strdup (tz_location_get_zone (g_ptr_array_index (locs, i))));
-	}
-
 	w = gst_dialog_get_widget (tool->main_dialog, "location_combo");
-	gtk_combo_set_popdown_strings (GTK_COMBO (w), combo_locs);
+	locs = tz_get_locations (e_tz_map_get_tz_db (tzmap));
+
+	for (i = 0; g_ptr_array_index (locs, i); i++)
+		gtk_combo_box_append_text (GTK_COMBO_BOX (w), g_strdup (tz_location_get_zone (g_ptr_array_index (locs, i))));
 }
 
 #define is_leap_year(yyy) ((((yyy % 4) == 0) && ((yyy % 100) != 0)) || ((yyy % 400) == 0));
@@ -311,7 +308,7 @@ timezone_construct_dialog (GstDialog *dialog)
 	g_return_if_fail (GST_IS_DIALOG(dialog));
 	
 	d = gtk_dialog_new_with_buttons (_("Time Zone"),
-					 NULL,
+					 GTK_WINDOW (dialog),
 					 GTK_DIALOG_MODAL | GTK_DIALOG_NO_SEPARATOR,
 					 GTK_STOCK_CLOSE,
 					 GTK_RESPONSE_CLOSE, NULL);
@@ -421,11 +418,10 @@ server_construct_dialog (GstDialog *dialog)
 	g_return_if_fail (GST_IS_DIALOG(dialog));
 
 	d = gtk_dialog_new_with_buttons (_("Time Servers"),
-					      NULL,
-					      GTK_DIALOG_MODAL |
-					      GTK_DIALOG_NO_SEPARATOR,
-					      GTK_STOCK_CLOSE,
-					      GTK_RESPONSE_CLOSE, NULL);
+					 GTK_WINDOW (dialog),
+					 GTK_DIALOG_MODAL | GTK_DIALOG_NO_SEPARATOR,
+					 GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+					 NULL);
 
 	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (d)), 5);
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (d)->vbox), 2);
@@ -495,12 +491,21 @@ ntp_use_toggled (GtkWidget *w, GstDialog *dialog)
 	ntp_installed = (gboolean) g_object_get_data (G_OBJECT (dialog->tool), "ntpinstalled");
 	
 	if (configured && !ntp_installed && active) {
-		GtkWidget *dialog;
+		GtkWidget *message;
 		
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), FALSE);
-		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, _("You don't have NTP support running. Please run NTP support in the system to enable server synchronization."));
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
+
+		message = gst_hig_dialog_new (GTK_WINDOW (dialog),
+					      GTK_DIALOG_MODAL,
+					      GST_HIG_MESSAGE_INFO,
+					      _("NTP support is not running"),
+					      _("Please run NTP support in the system to enable "
+						"synchronization of your local time server with internet time servers"),
+					      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+					      NULL);
+		gtk_dialog_run (GTK_DIALOG (message));
+
+		gtk_widget_destroy (message);
 		return;
 	}
 
@@ -786,11 +791,13 @@ gst_time_connect_calendar_signals (GstTimeTool *tool)
 static void
 gst_time_configure_calendar (GstTimeTool *tool)
 {
-	gint firstday;
+	gint firstday = 0;
 	GtkWidget *calendar = gst_dialog_get_widget (GST_TOOL (tool)->main_dialog, "calendar");
 
+#ifndef __FreeBSD__
 	setlocale (LC_ALL, "");
 	firstday = (int) *(nl_langinfo (_NL_TIME_FIRST_WEEKDAY));
+#endif
 
 	if (firstday == 1) 
 		gtk_calendar_display_options (GTK_CALENDAR (calendar), GTK_CALENDAR_WEEK_START_MONDAY | GTK_CALENDAR_SHOW_HEADING | GTK_CALENDAR_SHOW_DAY_NAMES);
